@@ -10,7 +10,7 @@ def main():
     etld_lib_spawn_etl.log_file_rotate_path = etld_lib_config.kb_log_rotate_file
     etld_lib_spawn_etl.lock_file = etld_lib_config.kb_lock_file
     etld_lib_spawn_etl.log_file_max_size = (1024 * 100000)          # 1024 * size = Max Meg Size
-    etld_lib_spawn_etl.spawned_process_max_run_time = (60*20)       # (seconds * minutes), then terminate as there is an issue.
+    etld_lib_spawn_etl.spawned_process_max_run_time = 14400          # seconds before terminate as there is an issue.
     etld_lib_spawn_etl.spawned_process_sleep_time = 5               # check every n seconds for spawned_process.is_alive()
     etld_lib_spawn_etl.spawned_process_count_to_status_update = 11  # Every n checks print status spawned_process.is_alive()
 
@@ -18,7 +18,7 @@ def main():
     etld_lib_spawn_etl.target_method_in_module_to_run = "kb_etl_workflow"
 
     etld_lib_spawn_etl.etl_dir_to_monitor = etld_lib_config.qetl_user_data_dir
-    etld_lib_spawn_etl.etl_files_max_time_between_changes = 300
+    etld_lib_spawn_etl.etl_files_max_time_between_changes = 1800
 
     etld_lib_spawn_etl.etl_main()
 
