@@ -50,6 +50,7 @@ global host_list_data_dir
 global host_list_export_dir
 global host_list_vm_processed_after
 global host_list_payload_option
+global host_list_show_tags
 global host_list_xml_file_list
 global host_list_other_xml_file
 global host_list_ec2_xml_file
@@ -425,6 +426,7 @@ def get_host_list_user_config():
     global qetl_user_config_settings_yaml_file
     global host_list_vm_processed_after
     global host_list_payload_option
+    global host_list_show_tags
     global qetl_manage_user_selected_datetime
     global host_list_csv_truncate_cell_limit
     global host_list_sqlite_file
@@ -434,6 +436,11 @@ def get_host_list_user_config():
     host_list_vm_processed_after = etld_lib_config_settings_yaml_dict.get('host_list_vm_processed_after')
     host_list_payload_option = etld_lib_config_settings_yaml_dict.get('host_list_payload_option')
 
+    if 'host_list_show_tags' in etld_lib_config_settings_yaml_dict.keys():
+        host_list_show_tags = etld_lib_config_settings_yaml_dict.get('host_list_show_tags')
+    else:
+        host_list_show_tags = '0'
+
     etld_lib_functions.logger.info(f"host list config - {qetl_user_config_settings_yaml_file}")
     etld_lib_functions.logger.info(f"host_list_export_dir yaml - {host_list_export_dir}")
 
